**To delete a chat LoggingConfiguration resource**

The following ``delete-logging-configuration`` example deletes the LoggingConfiguration resource for the specified ARN. ::

    aws ivschat delete-logging-configuration \
        --identifier "arn:aws:ivschat:us-west-2:123456789012:logging-configuration/ABcdef34ghIJ"

This command produces no output.

For more information, see `Getting Started with Amazon IVS Chat <https://docs.aws.amazon.com/ivs/latest/userguide/getting-started-chat.html>`__ in the *Amazon Interactive Video Service User Guide*.